==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/DatabricksArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.DatabricksArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * A DataFactory compute.
 * @property computeLocation Location for the underlying compute
 * @property computeType The type of compute
 * Expected value is 'Databricks'.
 * @property description The description of the Machine Learning compute.
 * @property disableLocalAuth Opt-out of local authentication and ensure customers can use only MSI and AAD exclusively for authentication.
 * @property properties Properties of Databricks
 * @property resourceId ARM resource id of the underlying compute
 */
public data class DatabricksArgs(
    public val computeLocation: Output<String>? = null,
    public val computeType: Output<String>,
    public val description: Output<String>? = null,
    public val disableLocalAuth: Output<Boolean>? = null,
    public val properties: Output<DatabricksPropertiesArgs>? = null,
    public val resourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.DatabricksArgs> {
    override fun toJava(): com.pulumi.azurenative.machinelearningservices.inputs.DatabricksArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.DatabricksArgs.builder()
            .computeLocation(computeLocation?.applyValue({ args0 -> args0 }))
            .computeType(computeType.applyValue({ args0 -> args0 }))
            .description(description?.applyValue({ args0 -> args0 }))
            .disableLocalAuth(disableLocalAuth?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceId(resourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DatabricksArgs].
 */
@PulumiTagMarker
public class DatabricksArgsBuilder internal constructor() {
    private var computeLocation: Output<String>? = null

    private var computeType: Output<String>? = null

    private var description: Output<String>? = null

    private var disableLocalAuth: Output<Boolean>? = null

    private var properties: Output<DatabricksPropertiesArgs>? = null

    private var resourceId: Output<String>? = null

    /**
     * @param value Location for the underlying compute
     */
    @JvmName("iyuitrcogsugiyli")
    public suspend fun computeLocation(`value`: Output<String>) {
        this.computeLocation = value
    }

    /**
     * @param value The type of compute
     * Expected value is 'Databricks'.
     */
    @JvmName("wcvpkyixqwpqmsmi")
    public suspend fun computeType(`value`: Output<String>) {
        this.computeType = value
    }

    /**
     * @param value The description of the Machine Learning compute.
     */
    @JvmName("mreihjksetrbitan")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Opt-out of local authentication and ensure customers can use only MSI and AAD exclusively for authentication.
     */
    @JvmName("cfewaaehvmhdefdm")
    public suspend fun disableLocalAuth(`value`: Output<Boolean>) {
        this.disableLocalAuth = value
    }

    /**
     * @param value Properties of Databricks
     */
    @JvmName("cevlcurkcmmmuexe")
    public suspend fun properties(`value`: Output<DatabricksPropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value ARM resource id of the underlying compute
     */
    @JvmName("chpuvnrujevdjktt")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value Location for the underlying compute
     */
    @JvmName("amoynifogbrjsfwo")
    public suspend fun computeLocation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.computeLocation = mapped
    }

    /**
     * @param value The type of compute
     * Expected value is 'Databricks'.
     */
    @JvmName("gjxutbggpydigsrg")
    public suspend fun computeType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.computeType = mapped
    }

    /**
     * @param value The description of the Machine Learning compute.
     */
    @JvmName("wrfebdajghogpcuw")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Opt-out of local authentication and ensure customers can use only MSI and AAD exclusively for authentication.
     */
    @JvmName("koeubfxbksgrrgdd")
    public suspend fun disableLocalAuth(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.disableLocalAuth = mapped
    }

    /**
     * @param value Properties of Databricks
     */
    @JvmName("ksmjygbnruafwfti")
    public suspend fun properties(`value`: DatabricksPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument Properties of Databricks
     */
    @JvmName("ttvfnemswitchefg")
    public suspend fun properties(argument: suspend DatabricksPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = DatabricksPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value ARM resource id of the underlying compute
     */
    @JvmName("kcfrqbbjpufmsoev")
    public suspend fun resourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    internal fun build(): DatabricksArgs = DatabricksArgs(
        computeLocation = computeLocation,
        computeType = computeType ?: throw PulumiNullFieldException("computeType"),
        description = description,
        disableLocalAuth = disableLocalAuth,
        properties = properties,
        resourceId = resourceId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/DatabricksArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.DatabricksArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * A DataFactory compute.
 * @property computeLocation Location for the underlying compute
 * @property computeType The type of compute
 * Expected value is 'Databricks'.
 * @property description The description of the Machine Learning compute.
 * @property disableLocalAuth Opt-out of local authentication and ensure customers can use only MSI and AAD exclusively for authentication.
 * @property properties Properties of Databricks
 * @property resourceId ARM resource id of the underlying compute
 */
public data class DatabricksArgs(
    public val computeLocation: Output<String>? = null,
    public val computeType: Output<String>,
    public val description: Output<String>? = null,
    public val disableLocalAuth: Output<Boolean>? = null,
    public val properties: Output<DatabricksPropertiesArgs>? = null,
    public val resourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.DatabricksArgs> {
    override fun toJava(): com.pulumi.azurenative.machinelearningservices.inputs.DatabricksArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.DatabricksArgs.builder()
            .computeLocation(computeLocation?.applyValue({ args0 -> args0 }))
            .computeType(computeType.applyValue({ args0 -> args0 }))
            .description(description?.applyValue({ args0 -> args0 }))
            .disableLocalAuth(disableLocalAuth?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceId(resourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DatabricksArgs].
 */
@PulumiTagMarker
public class DatabricksArgsBuilder internal constructor() {
    private var computeLocation: Output<String>? = null

    private var computeType: Output<String>? = null

    private var description: Output<String>? = null

    private var disableLocalAuth: Output<Boolean>? = null

    private var properties: Output<DatabricksPropertiesArgs>? = null

    private var resourceId: Output<String>? = null

    /**
     * @param value Location for the underlying compute
     */
    @JvmName("okfgsmcmstkolajv")
    public suspend fun computeLocation(`value`: Output<String>) {
        this.computeLocation = value
    }

    /**
     * @param value The type of compute
     * Expected value is 'Databricks'.
     */
    @JvmName("ryqfmedmdbyubmci")
    public suspend fun computeType(`value`: Output<String>) {
        this.computeType = value
    }

    /**
     * @param value The description of the Machine Learning compute.
     */
    @JvmName("whybyrynsdefreup")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value Opt-out of local authentication and ensure customers can use only MSI and AAD exclusively for authentication.
     */
    @JvmName("cngilyrqonslmjge")
    public suspend fun disableLocalAuth(`value`: Output<Boolean>) {
        this.disableLocalAuth = value
    }

    /**
     * @param value Properties of Databricks
     */
    @JvmName("ahtovjhqnaomgbhk")
    public suspend fun properties(`value`: Output<DatabricksPropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value ARM resource id of the underlying compute
     */
    @JvmName("kpykdffwkwudvofj")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value Location for the underlying compute
     */
    @JvmName("srympaqcihgrgqfr")
    public suspend fun computeLocation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.computeLocation = mapped
    }

    /**
     * @param value The type of compute
     * Expected value is 'Databricks'.
     */
    @JvmName("forxwhsshlywnopv")
    public suspend fun computeType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.computeType = mapped
    }

    /**
     * @param value The description of the Machine Learning compute.
     */
    @JvmName("uagumudorrweribq")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value Opt-out of local authentication and ensure customers can use only MSI and AAD exclusively for authentication.
     */
    @JvmName("pnqwkotrolcudhoa")
    public suspend fun disableLocalAuth(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.disableLocalAuth = mapped
    }

    /**
     * @param value Properties of Databricks
     */
    @JvmName("dxoamqcqbwbohahp")
    public suspend fun properties(`value`: DatabricksPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument Properties of Databricks
     */
    @JvmName("bciceegcruwbohxf")
    public suspend fun properties(argument: suspend DatabricksPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = DatabricksPropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value ARM resource id of the underlying compute
     */
    @JvmName("ispmkgmnncrjifiw")
    public suspend fun resourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    internal fun build(): DatabricksArgs = DatabricksArgs(
        computeLocation = computeLocation,
        computeType = computeType ?: throw PulumiNullFieldException("computeType"),
        description = description,
        disableLocalAuth = disableLocalAuth,
        properties = properties,
        resourceId = resourceId,
    )
}
